@@ -711,6 +711,9 @@ static const struct {
     {NM_CONFIG_KEYFILE_GROUP_MAIN, NM_CONFIG_KEYFILE_KEY_MAIN_IWD_CONFIG_PATH, ""},
     {NM_CONFIG_KEYFILE_GROUP_LOGGING, "backend", NM_CONFIG_DEFAULT_LOGGING_BACKEND},
     {NM_CONFIG_KEYFILE_GROUP_LOGGING, "audit", NM_CONFIG_DEFAULT_LOGGING_AUDIT},
+    {NM_CONFIG_KEYFILE_GROUPPREFIX_DEVICE,
+     NM_CONFIG_KEYFILE_KEY_DEVICE_WIFI_BACKEND,
+     NM_CONFIG_DEFAULT_WIFI_BACKEND},
 };
 
 void
@@ -836,6 +839,13 @@ nm_config_data_log(const NMConfigData  *self,
             _LOG(stream, prefix, "# no-auto-default specs \"%s\"", msg);
     }
 
+    if (nm_config_kernel_command_line_nm_debug()) {
+        _LOG(stream,
+             prefix,
+             "# /proc/cmdline contains \"" NM_CONFIG_KERNEL_CMDLINE_NM_DEBUG
+             "\". Debug log enabled");
+    }
+
 #undef _LOG
 }
 
