@@ -487,6 +487,17 @@ nm_streq0(const char *s1, const char *s2)
     return (s1 == s2) || (s1 && s2 && strcmp(s1, s2) == 0);
 }
 
+static inline int
+nm_memcmp(const void *s1, const void *s2, size_t n)
+{
+    /* Workaround undefined behavior in memcmp() with NULL pointers. */
+    if (n == 0)
+        return 0;
+    nm_assert(s1);
+    nm_assert(s2);
+    return memcmp(s1, s2, n);
+}
+
 /*
  * Very similar to g_str_has_prefix() with the obvious meaning.
  * Differences:
@@ -1163,7 +1174,7 @@ nm_ptr_to_uintptr(const void *p)
 
 #define NM_CMP_DIRECT_BOOL(a, b) NM_CMP_DIRECT(!!(a), !!(b))
 
-#define NM_CMP_DIRECT_MEMCMP(a, b, size) NM_CMP_RETURN(memcmp((a), (b), (size)))
+#define NM_CMP_DIRECT_MEMCMP(a, b, size) NM_CMP_RETURN(nm_memcmp((a), (b), (size)))
 
 #define NM_CMP_DIRECT_STRCMP(a, b) NM_CMP_RETURN_DIRECT(strcmp((a), (b)))
 
